@@ -1,4 +1,6 @@
 import contextlib
+import signal
+import sys
 
 from . import const
 from . import helpers
@@ -30,6 +32,11 @@ def connected(*,
               ) -> None:
     """Context manager for managing the connection with a MT5 terminal using the python ``with`` statement.
 
+    >>> mt5_connected = mt5.connected(raise_on_errors=True, ensure_trade_enabled=True)
+    >>> with mt5_connected:
+    ...     print(mt5.symbols_get())
+    >>>
+
     :param path:  Path to terminal.
     :param portable: Load terminal in portable mode.
     :param server:  Server name.
@@ -79,3 +86,64 @@ def connected(*,
         if debug_logging:
             log("MT5 connection has been shutdown.")
         _state.set_defaults()
+
+
+def _sigterm_handler(signum, frame):
+    sys.exit(0)
+
+
+_sigterm_handler.__enter_ctx__ = False
+
+
+@contextlib.contextmanager
+def handle_exit(callback=None, append=False):
+    """A context manager which properly handles SIGTERM and SIGINT
+    (KeyboardInterrupt) signals, registering a function which is
+    guaranteed to be called after signals are received.
+    Also, it makes sure to execute previously registered signal
+    handlers as well (if any).
+
+    >>> app = App()
+    >>> with handle_exit(app.stop):
+    ...     app.start()
+    ...
+    >>>
+
+    If append == False raise RuntimeError if there's already a handler
+    registered for SIGTERM, otherwise both new and old handlers are
+    executed in this order.
+    """
+    old_handler = signal.signal(signal.SIGTERM, _sigterm_handler)
+    if (old_handler != signal.SIG_DFL) and (old_handler != _sigterm_handler):
+        if not append:
+            raise RuntimeError("there is already a handler registered for "
+                               "SIGTERM: %r" % old_handler)
+
+        def handler(signum, frame):
+            try:
+                _sigterm_handler(signum, frame)
+            finally:
+                old_handler(signum, frame)
+
+        signal.signal(signal.SIGTERM, handler)
+
+    if _sigterm_handler.__enter_ctx__:
+        raise RuntimeError("can't use nested contexts")
+    _sigterm_handler.__enter_ctx__ = True
+
+    try:
+        yield
+    except KeyboardInterrupt:
+        pass
+    except SystemExit as err:
+        # code != 0 refers to an application error (e.g. explicit
+        # sys.exit('some error') call).
+        # We don't want that to pass silently.
+        # Nevertheless, the 'finally' clause below will always
+        # be executed.
+        if err.code != 0:
+            raise
+    finally:
+        _sigterm_handler.__enter_ctx__ = False
+        if callback is not None:
+            callback()
