@@ -339,7 +339,7 @@ def copy_rates(symbol,
                 return _mt5.copy_rates_range(symbol, timeframe, datetime_from, datetime_to)
         if all(x is None for x in [datetime_from, datetime_to, start_pos]):
             start_pos = 0
-        count = count or _state.max_bars
+        count = min((count or _state.max_bars), _state.max_bars - 1)
         return _mt5.copy_rates_from_pos(symbol, timeframe, start_pos, count)
     except SystemError:
         return None
